@@ -9,6 +9,10 @@ import os
 import requests
 import json
 
+class SeedboxClientException(Exception): pass
+
+class TemporaryMalfunction(SeedboxClientException): pass
+
 class SeedboxClient:
 
     def __init__(self, local_download_dir):
@@ -16,6 +20,7 @@ class SeedboxClient:
 
     def get_finished_torrents(self):
         # This returns a series of tuples (torrentdescriptor, "Done") for every torrent that is done
+        # If there is a temporary error, it raises TemporaryMalfunction
         raise NotImplementedError
 
     def get_file_name(self, torrentname):
@@ -218,14 +223,22 @@ class PulsedMediaClient(SeedboxClient):
 		data="mode=list",
 		verify=False,
 	)
+	if r.status_code == 500:
+		raise TemporaryMalfunction(
+			"Server is experiencing a temporary 500 status code: %s"%\
+			r.content
+		)
 	assert r.status_code == 200, "Non-OK status code while retrieving get_finished_torrents: %r"%r.status_code
 	data = json.loads(r.content)
 	torrents = data["t"]
 	self.torrents_cache = torrents
-	self.path_for_filename_cache = dict([
-		(os.path.basename(torrent[25]), torrent[25])
-		for torrent in torrents.values()
-	])
+	try:
+		self.path_for_filename_cache = dict([
+			(os.path.basename(torrent[25]), torrent[25])
+			for torrent in torrents.values()
+		])
+	except AttributeError, e:
+		raise AttributeError, "normally this would be a 'list' object has no attribute 'values', but in reality something went wrong with the unserialization of JSON values, which were serialized from %r and were supposed to come from the 't' bag of JSON data -- this happens when PulsedMedia's server fucks up"%r.content
 	done_torrents = []
 	for key,torrent in torrents.items():
 		#filename = torrent[25]
